@@ -17,11 +17,12 @@ use uv_build_frontend::{SourceBuild, SourceBuildContext};
 use uv_cache::Cache;
 use uv_client::RegistryClient;
 use uv_configuration::{
-    BuildKind, BuildOptions, ConfigSettings, Constraints, IndexStrategy, PreviewMode, Reinstall,
-    SourceStrategy,
+    BuildKind, BuildOptions, ConfigSettings, Constraints, IndexStrategy, PackageConfigSettings,
+    Preview, Reinstall, SourceStrategy,
 };
 use uv_configuration::{BuildOutput, Concurrency};
 use uv_distribution::DistributionDatabase;
+use uv_distribution::ExtraBuildRequires;
 use uv_distribution_filename::DistFilename;
 use uv_distribution_types::{
     CachedDist, DependencyMetadata, Identifier, IndexCapabilities, IndexLocations,
@@ -88,17 +89,19 @@ pub struct BuildDispatch<'a> {
     shared_state: SharedState,
     dependency_metadata: &'a DependencyMetadata,
     build_isolation: BuildIsolation<'a>,
+    extra_build_requires: &'a ExtraBuildRequires,
     link_mode: uv_install_wheel::LinkMode,
     build_options: &'a BuildOptions,
     config_settings: &'a ConfigSettings,
+    config_settings_package: &'a PackageConfigSettings,
     hasher: &'a HashStrategy,
-    exclude_newer: Option<ExcludeNewer>,
+    exclude_newer: ExcludeNewer,
     source_build_context: SourceBuildContext,
     build_extra_env_vars: FxHashMap<OsString, OsString>,
     sources: SourceStrategy,
     workspace_cache: WorkspaceCache,
     concurrency: Concurrency,
-    preview: PreviewMode,
+    preview: Preview,
 }
 
 impl<'a> BuildDispatch<'a> {
@@ -113,15 +116,17 @@ impl<'a> BuildDispatch<'a> {
         shared_state: SharedState,
         index_strategy: IndexStrategy,
         config_settings: &'a ConfigSettings,
+        config_settings_package: &'a PackageConfigSettings,
         build_isolation: BuildIsolation<'a>,
+        extra_build_requires: &'a ExtraBuildRequires,
         link_mode: uv_install_wheel::LinkMode,
         build_options: &'a BuildOptions,
         hasher: &'a HashStrategy,
-        exclude_newer: Option<ExcludeNewer>,
+        exclude_newer: ExcludeNewer,
         sources: SourceStrategy,
         workspace_cache: WorkspaceCache,
         concurrency: Concurrency,
-        preview: PreviewMode,
+        preview: Preview,
     ) -> Self {
         Self {
             client,
@@ -134,7 +139,9 @@ impl<'a> BuildDispatch<'a> {
             dependency_metadata,
             index_strategy,
             config_settings,
+            config_settings_package,
             build_isolation,
+            extra_build_requires,
             link_mode,
             build_options,
             hasher,
@@ -200,6 +207,10 @@ impl BuildContext for BuildDispatch<'_> {
         self.config_settings
     }
 
+    fn config_settings_package(&self) -> &PackageConfigSettings {
+        self.config_settings_package
+    }
+
     fn sources(&self) -> SourceStrategy {
         self.sources
     }
@@ -212,6 +223,10 @@ impl BuildContext for BuildDispatch<'_> {
         &self.workspace_cache
     }
 
+    fn extra_build_dependencies(&self) -> &uv_workspace::pyproject::ExtraBuildDependencies {
+        &self.extra_build_requires.extra_build_dependencies
+    }
+
     async fn resolve<'data>(
         &'data self,
         requirements: &'data [Requirement],
@@ -224,7 +239,7 @@ impl BuildContext for BuildDispatch<'_> {
         let resolver = Resolver::new(
             Manifest::simple(requirements.to_vec()).with_constraints(self.constraints.clone()),
             OptionsBuilder::new()
-                .exclude_newer(self.exclude_newer)
+                .exclude_newer(self.exclude_newer.clone())
                 .index_strategy(self.index_strategy)
                 .build_options(self.build_options.clone())
                 .flexibility(Flexibility::Fixed)
@@ -295,6 +310,7 @@ impl BuildContext for BuildDispatch<'_> {
             self.hasher,
             self.index_locations,
             self.config_settings,
+            self.config_settings_package,
             self.cache(),
             venv,
             tags,
@@ -418,6 +434,17 @@ impl BuildContext for BuildDispatch<'_> {
             build_stack.insert(dist.distribution_id());
         }
 
+        // Get package-specific config settings if available; otherwise, use global settings.
+        let config_settings = if let Some(name) = dist_name {
+            if let Some(package_settings) = self.config_settings_package.get(name) {
+                package_settings.clone().merge(self.config_settings.clone())
+            } else {
+                self.config_settings.clone()
+            }
+        } else {
+            self.config_settings.clone()
+        };
+
         let builder = SourceBuild::setup(
             source,
             subdirectory,
@@ -431,8 +458,9 @@ impl BuildContext for BuildDispatch<'_> {
             self.index_locations,
             sources,
             self.workspace_cache(),
-            self.config_settings.clone(),
+            config_settings,
             self.build_isolation,
+            &self.extra_build_requires.extra_build_dependencies,
             &build_stack,
             build_kind,
             self.build_extra_env_vars.clone(),
