@@ -73,6 +73,7 @@ pub use crate::pip_index::*;
 pub use crate::prioritized_distribution::*;
 pub use crate::requested::*;
 pub use crate::requirement::*;
+pub use crate::requires_python::*;
 pub use crate::resolution::*;
 pub use crate::resolved::*;
 pub use crate::specified_requirement::*;
@@ -100,6 +101,7 @@ mod pip_index;
 mod prioritized_distribution;
 mod requested;
 mod requirement;
+mod requires_python;
 mod resolution;
 mod resolved;
 mod specified_requirement;
@@ -341,9 +343,9 @@ pub struct DirectorySourceDist {
     /// The absolute path to the distribution which we use for installing.
     pub install_path: Box<Path>,
     /// Whether the package should be installed in editable mode.
-    pub editable: bool,
+    pub editable: Option<bool>,
     /// Whether the package should be built and installed.
-    pub r#virtual: bool,
+    pub r#virtual: Option<bool>,
     /// The URL as it was provided by the user.
     pub url: VerbatimUrl,
 }
@@ -450,8 +452,8 @@ impl Dist {
         name: PackageName,
         url: VerbatimUrl,
         install_path: &Path,
-        editable: bool,
-        r#virtual: bool,
+        editable: Option<bool>,
+        r#virtual: Option<bool>,
     ) -> Result<Dist, Error> {
         // Convert to an absolute path.
         let install_path = path::absolute(install_path)?;
@@ -653,7 +655,7 @@ impl SourceDist {
     /// Returns `true` if the distribution is editable.
     pub fn is_editable(&self) -> bool {
         match self {
-            Self::Directory(DirectorySourceDist { editable, .. }) => *editable,
+            Self::Directory(DirectorySourceDist { editable, .. }) => editable.unwrap_or(false),
             _ => false,
         }
     }
@@ -661,7 +663,7 @@ impl SourceDist {
     /// Returns `true` if the distribution is virtual.
     pub fn is_virtual(&self) -> bool {
         match self {
-            Self::Directory(DirectorySourceDist { r#virtual, .. }) => *r#virtual,
+            Self::Directory(DirectorySourceDist { r#virtual, .. }) => r#virtual.unwrap_or(false),
             _ => false,
         }
     }
