@@ -91,13 +91,21 @@ impl CompatibleDist<'_> {
         }
     }
 
+    // For installable distributions, return the prioritized distribution it was derived from.
+    pub fn prioritized(&self) -> Option<&PrioritizedDist> {
+        match self {
+            CompatibleDist::InstalledDist(_) => None,
+            CompatibleDist::SourceDist { prioritized, .. }
+            | CompatibleDist::CompatibleWheel { prioritized, .. }
+            | CompatibleDist::IncompatibleWheel { prioritized, .. } => Some(prioritized),
+        }
+    }
+
     /// Return the set of supported platform the distribution, in terms of their markers.
     pub fn implied_markers(&self) -> MarkerTree {
-        match self {
-            CompatibleDist::InstalledDist(_) => MarkerTree::TRUE,
-            CompatibleDist::SourceDist { prioritized, .. } => prioritized.0.markers,
-            CompatibleDist::CompatibleWheel { prioritized, .. } => prioritized.0.markers,
-            CompatibleDist::IncompatibleWheel { prioritized, .. } => prioritized.0.markers,
+        match self.prioritized() {
+            Some(prioritized) => prioritized.0.markers,
+            None => MarkerTree::TRUE,
         }
     }
 }
@@ -831,7 +839,7 @@ pub fn implied_markers(filename: &WheelFilename) -> MarkerTree {
                 tag_marker.and(MarkerTree::expression(MarkerExpression::String {
                     key: MarkerValueString::PlatformMachine,
                     operator: MarkerOperator::Equal,
-                    value: arcstr::literal!("x86_64"),
+                    value: arcstr::literal!("AMD64"),
                 }));
                 marker.or(tag_marker);
             }
@@ -925,7 +933,7 @@ mod tests {
         );
         assert_markers(
             "numpy-2.2.1-cp313-cp313t-win_amd64.whl",
-            "sys_platform == 'win32' and platform_machine == 'x86_64'",
+            "sys_platform == 'win32' and platform_machine == 'AMD64'",
         );
         assert_markers(
             "numpy-2.2.1-cp313-cp313t-win_arm64.whl",
