@@ -225,6 +225,9 @@ impl EnvVars {
     /// Equivalent to the `--preview` argument. Enables preview mode.
     pub const UV_PREVIEW: &'static str = "UV_PREVIEW";
 
+    /// Equivalent to the `--preview-features` argument. Enables specific preview features.
+    pub const UV_PREVIEW_FEATURES: &'static str = "UV_PREVIEW_FEATURES";
+
     /// Equivalent to the `--token` argument for self update. A GitHub token for authentication.
     pub const UV_GITHUB_TOKEN: &'static str = "UV_GITHUB_TOKEN";
 
@@ -257,6 +260,10 @@ impl EnvVars {
     /// Specifies the "bin" directory for installing tool executables.
     pub const UV_TOOL_BIN_DIR: &'static str = "UV_TOOL_BIN_DIR";
 
+    /// Equivalent to the `--build-backend` argument for `uv init`. Determines the default backend
+    /// to use when creating a new project.
+    pub const UV_INIT_BUILD_BACKEND: &'static str = "UV_INIT_BUILD_BACKEND";
+
     /// Specifies the path to the directory to use for a project virtual environment.
     ///
     /// See the [project documentation](../concepts/projects/config.md#project-environment-path)
@@ -724,9 +731,15 @@ impl EnvVars {
     /// the installer from modifying shell profiles or environment variables.
     pub const UV_UNMANAGED_INSTALL: &'static str = "UV_UNMANAGED_INSTALL";
 
+    /// The URL from which to download uv using the standalone installer. By default, installs from
+    /// uv's GitHub Releases. `INSTALLER_DOWNLOAD_URL` is also supported as an alias, for backwards
+    /// compatibility.
+    pub const UV_DOWNLOAD_URL: &'static str = "UV_DOWNLOAD_URL";
+
     /// Avoid modifying the `PATH` environment variable when installing uv using the standalone
-    /// installer and `self update` feature.
-    pub const INSTALLER_NO_MODIFY_PATH: &'static str = "INSTALLER_NO_MODIFY_PATH";
+    /// installer and `self update` feature. `INSTALLER_NO_MODIFY_PATH` is also supported as an
+    /// alias, for backwards compatibility.
+    pub const UV_NO_MODIFY_PATH: &'static str = "UV_NO_MODIFY_PATH";
 
     /// Skip writing `uv` installer metadata files (e.g., `INSTALLER`, `REQUESTED`, and `direct_url.json`) to site-packages `.dist-info` directories.
     pub const UV_NO_INSTALLER_METADATA: &'static str = "UV_NO_INSTALLER_METADATA";
