@@ -8,18 +8,17 @@ use std::fmt::Write;
 use std::path::PathBuf;
 use std::sync::Arc;
 use tracing::debug;
-use uv_tool::InstalledTools;
 
 use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, RegistryClient};
 use uv_configuration::{
     BuildOptions, Concurrency, ConfigSettings, Constraints, DependencyGroups, DryRun,
-    ExtrasSpecification, Overrides, Reinstall, Upgrade,
+    ExtrasSpecification, Overrides, PackageConfigSettings, Reinstall, Upgrade,
 };
 use uv_dispatch::BuildDispatch;
-use uv_distribution::DistributionDatabase;
+use uv_distribution::{DistributionDatabase, SourcedDependencyGroups};
 use uv_distribution_types::{
-    CachedDist, Diagnostic, InstalledDist, LocalDist, NameRequirementSpecification,
+    CachedDist, Diagnostic, InstalledDist, LocalDist, NameRequirementSpecification, Requirement,
     ResolutionDiagnostic, UnresolvedRequirement, UnresolvedRequirementSpecification,
 };
 use uv_distribution_types::{
@@ -28,19 +27,21 @@ use uv_distribution_types::{
 use uv_fs::Simplified;
 use uv_install_wheel::LinkMode;
 use uv_installer::{Plan, Planner, Preparer, SitePackages};
-use uv_normalize::{GroupName, PackageName};
+use uv_normalize::PackageName;
+use uv_pep508::{MarkerEnvironment, RequirementOrigin};
 use uv_platform_tags::Tags;
 use uv_pypi_types::{Conflicts, ResolverMarkerEnvironment};
 use uv_python::{PythonEnvironment, PythonInstallation};
 use uv_requirements::{
-    LookaheadResolver, NamedRequirementsResolver, RequirementsSource, RequirementsSpecification,
-    SourceTreeResolver,
+    GroupsSpecification, LookaheadResolver, NamedRequirementsResolver, RequirementsSource,
+    RequirementsSpecification, SourceTreeResolver,
 };
 use uv_resolver::{
     DependencyMode, Exclusions, FlatIndex, InMemoryIndex, Manifest, Options, Preference,
     Preferences, PythonRequirement, Resolver, ResolverEnvironment, ResolverOutput,
 };
-use uv_types::{HashStrategy, InFlight, InstalledPackagesProvider};
+use uv_tool::InstalledTools;
+use uv_types::{BuildContext, HashStrategy, InFlight, InstalledPackagesProvider};
 use uv_warnings::warn_user;
 
 use crate::commands::pip::loggers::{DefaultInstallLogger, InstallLogger, ResolveLogger};
@@ -54,7 +55,7 @@ pub(crate) async fn read_requirements(
     constraints: &[RequirementsSource],
     overrides: &[RequirementsSource],
     extras: &ExtrasSpecification,
-    groups: BTreeMap<PathBuf, Vec<GroupName>>,
+    groups: Option<&GroupsSpecification>,
     client_builder: &BaseClientBuilder<'_>,
 ) -> Result<RequirementsSpecification, Error> {
     // If the user requests `extras` but does not provide a valid source (e.g., a `pyproject.toml`),
@@ -69,7 +70,7 @@ pub(crate) async fn read_requirements(
             "Use `package[extra]` syntax instead."
         };
         return Err(anyhow!(
-            "Requesting extras requires a `pyproject.toml`, `setup.cfg`, or `setup.py` file. {hint}"
+            "Requesting extras requires a `pylock.toml`, `pyproject.toml`, `setup.cfg`, or `setup.py` file. {hint}"
         )
         .into());
     }
@@ -90,15 +91,11 @@ pub(crate) async fn read_constraints(
     constraints: &[RequirementsSource],
     client_builder: &BaseClientBuilder<'_>,
 ) -> Result<Vec<NameRequirementSpecification>, Error> {
-    Ok(RequirementsSpecification::from_sources(
-        &[],
-        constraints,
-        &[],
-        BTreeMap::default(),
-        client_builder,
+    Ok(
+        RequirementsSpecification::from_sources(&[], constraints, &[], None, client_builder)
+            .await?
+            .constraints,
     )
-    .await?
-    .constraints)
 }
 
 /// Resolve a set of requirements, similar to running `pip compile`.
@@ -119,6 +116,7 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
     tags: Option<&Tags>,
     resolver_env: ResolverEnvironment,
     python_requirement: PythonRequirement,
+    current_environment: &MarkerEnvironment,
     conflicts: Conflicts,
     client: &RegistryClient,
     flat_index: &FlatIndex,
@@ -164,7 +162,6 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
         if !source_trees.is_empty() {
             let resolutions = SourceTreeResolver::new(
                 extras,
-                groups,
                 hasher,
                 index,
                 DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
@@ -210,6 +207,47 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
             );
         }
 
+        for (pyproject_path, groups) in groups {
+            let metadata = SourcedDependencyGroups::from_virtual_project(
+                pyproject_path,
+                None,
+                build_dispatch.locations(),
+                build_dispatch.sources(),
+                build_dispatch.workspace_cache(),
+            )
+            .await
+            .map_err(|e| {
+                anyhow!(
+                    "Failed to read dependency groups from: {}\n{}",
+                    pyproject_path.display(),
+                    e
+                )
+            })?;
+
+            // Complain if dependency groups are named that don't appear.
+            for name in groups.explicit_names() {
+                if !metadata.dependency_groups.contains_key(name) {
+                    return Err(anyhow!(
+                        "The dependency group '{name}' was not found in the project: {}",
+                        pyproject_path.user_display()
+                    ))?;
+                }
+            }
+            // Apply dependency-groups
+            for (group_name, group) in &metadata.dependency_groups {
+                if groups.contains(group_name) {
+                    requirements.extend(group.iter().cloned().map(|group| Requirement {
+                        origin: Some(RequirementOrigin::Group(
+                            pyproject_path.clone(),
+                            metadata.name.clone(),
+                            group_name.clone(),
+                        )),
+                        ..group
+                    }));
+                }
+            }
+        }
+
         requirements
     };
 
@@ -303,6 +341,7 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
             options,
             &python_requirement,
             resolver_env,
+            current_environment,
             conflicts,
             tags,
             flat_index,
@@ -402,6 +441,7 @@ pub(crate) async fn install(
     compile: bool,
     index_urls: &IndexLocations,
     config_settings: &ConfigSettings,
+    config_settings_package: &PackageConfigSettings,
     hasher: &HashStrategy,
     tags: &Tags,
     client: &RegistryClient,
@@ -427,6 +467,7 @@ pub(crate) async fn install(
             hasher,
             index_urls,
             config_settings,
+            config_settings_package,
             cache,
             venv,
             tags,
