@@ -1,13 +1,13 @@
 use anyhow::Result;
 use itertools::Itertools;
-use owo_colors::OwoColorize;
+use owo_colors::{AnsiColors, OwoColorize};
 use std::collections::BTreeMap;
 use std::fmt::Write;
 use tracing::debug;
 
 use uv_cache::Cache;
 use uv_client::BaseClientBuilder;
-use uv_configuration::{Concurrency, Constraints, DryRun, PreviewMode};
+use uv_configuration::{Concurrency, Constraints, DryRun, Preview};
 use uv_distribution_types::Requirement;
 use uv_fs::CWD;
 use uv_normalize::PackageName;
@@ -18,7 +18,8 @@ use uv_python::{
 use uv_requirements::RequirementsSpecification;
 use uv_settings::{Combine, PythonInstallMirrors, ResolverInstallerOptions, ToolOptions};
 use uv_tool::InstalledTools;
-use uv_workspace::WorkspaceCache;
+use uv_warnings::write_error_chain;
+use uv_workspace::{WorkspaceCache, pyproject::ExtraBuildDependencies};
 
 use crate::commands::pip::loggers::{
     DefaultInstallLogger, SummaryResolveLogger, UpgradeInstallLogger,
@@ -47,7 +48,7 @@ pub(crate) async fn upgrade(
     concurrency: Concurrency,
     cache: &Cache,
     printer: Printer,
-    preview: PreviewMode,
+    preview: Preview,
 ) -> Result<ExitStatus> {
     let installed_tools = InstalledTools::from_settings()?.init()?;
     let _lock = installed_tools.lock().await?;
@@ -155,20 +156,13 @@ pub(crate) async fn upgrade(
             .into_iter()
             .sorted_unstable_by(|(name_a, _), (name_b, _)| name_a.cmp(name_b))
         {
-            writeln!(
+            write_error_chain(
+                err.context(format!("Failed to upgrade {}", name.green()))
+                    .as_ref(),
                 printer.stderr(),
-                "{}: Failed to upgrade {}",
-                "error".red().bold(),
-                name.green()
+                "error",
+                AnsiColors::Red,
             )?;
-            for err in err.chain() {
-                writeln!(
-                    printer.stderr(),
-                    "  {}: {}",
-                    "Caused by".red().bold(),
-                    err.to_string().trim()
-                )?;
-            }
         }
         return Ok(ExitStatus::Failure);
     }
@@ -221,7 +215,7 @@ async fn upgrade_tool(
     filesystem: &ResolverInstallerOptions,
     installer_metadata: bool,
     concurrency: Concurrency,
-    preview: PreviewMode,
+    preview: Preview,
 ) -> Result<UpgradeOutcome> {
     // Ensure the tool is installed.
     let existing_tool_receipt = match installed_tools.get_tool_receipt(name) {
@@ -343,6 +337,7 @@ async fn upgrade_tool(
             spec,
             Modifications::Exact,
             build_constraints,
+            uv_distribution::ExtraBuildRequires::from_lowered(ExtraBuildDependencies::default()),
             &settings,
             network_settings,
             &state,
